@@ -2,7 +2,9 @@ import unittest
 
 import os
 
+import pytest
 
+@pytest.mark.skip()
 class TestEval(unittest.TestCase):
 
     def testHelp(self):
@@ -30,7 +32,7 @@ class TestEval(unittest.TestCase):
 
     def testEvalClassify(self):
         result = os.system(
-            'tfkit-eval --model ./cache/10.pt --tag clas --valid ../demo_data/classification.csv --metric clas --print  ')
+            'tfkit-eval --model ./cache/1.pt --valid ../demo_data/classification.csv --metric clas')
         self.assertTrue(result == 0)
 
     def testEvalQA(self):
